/*************************************************************************/
/* Nom : fichier global.h                                                */
/*                                                                       */
/* Role : Declaration des variables globales                             */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 15/12/1996 | Creation du fichier                                */
/*     |            |                                                    */
/* PDB | 20/12/1996 | ajout definition structures et constantes          */
/*     |            |                                                    */
/* PDB | 20/02/1997 | Ajout de la variable G_etatCurseur                 */
/*     |            |                                                    */
/* PDB | 21/02/1997 | Ajout de la variable G_joueurAdverse               */
/*     |            |                                                    */
/* PDB | 23/02/1997 | Ajout de la variable G_ordinateur                  */
/*     |            |                                                    */
/* PDB | 24/02/1997 | Ajout de la constante NOMBRE_COUPS                 */
/*     |            |                                                    */
/* PDB | 19/03/1997 | Ajout de la variable G_resolution                  */
/*     |            |                                                    */
/* PDB | 24/03/1997 | Ajout de constantes permettant la gestion des      */
/*     |            | differents etats d'une case                        */
/*     |            |                                                    */
/* PDB | 06/04/1997 | Ajout de G_choixTypeJeu et constante OK, ANNULER   */
/*     |            |                                                    */
/* PDB | 16/04/1997 | Ajout de G_statistique et suppression de G_nbPion  */
/*     |            |                                                    */
/* PDB | 18/04/1997 | Ajout de constantes pour les profondeurs des       */
/*     |            | algorithme de recherche                            */
/*     |            |                                                    */
/* PDB | 19/04/1997 | Ajout de variables permettant de gerer les coups   */
/*     |            | du jeu                                             */
/*     |            |                                                    */
/* PDB | 27/04/1997 | Ajout de variables permettant de gerer une saisie  */
/*     |            |                                                    */
/* PDB | 18/05/1997 | Ajout de variables pour la gestion des high scores */
/*     |            |                                                    */
/* PDB | 19/05/1997 | Ajout de variables pour la gestion des ouvertures  */
/*     |            |                                                    */
/* PDB | 21/06/1997 | Ajout de variables pour la gestion du temps de jeu */
/*     |            |                                                    */
/* PDB | 22/06/1997 | Ajout de variables pour l'arret de la recherche    */
/*     |            | en profondeur                                      */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Ajout de variables memorisant les noms saisies     */
/*     |            |                                                    */
/* PDB | 02/07/1997 | Ajout de variable autorisant l'arret d'OTHO        */
/*     |            |                                                    */
/* PDB | 10/08/1997 | Ajout de variable G_protectionEcriture             */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

#include <time.h>

#include "include\svgacc.h"
#include "include\type.h"

/*****************************/
/* Definition des structures */
/*****************************/

extern typeStructureCarteVideo	G_strCarteVideo;  /* caracteristique de la carte video */

/*************************************/
/* Definition des variables globales */
/*************************************/

extern  PaletteData G_gifPalette       ;  /* Palette couleur de l'image courante */

extern	RasterBlock far *G_ptrNombre[NOMBRE_CHIFFRE]  ;  /* nombre graphique de 0 a 9 */

extern	RasterBlock far *G_ptrPionJeu[NB_TYPE_CASE] ;  /* Definition des pions du jeu */
extern	RasterBlock far *G_ptrPion     ;
extern	RasterBlock far *G_ptrNombreTmp;  /* Nombre graphique Tampon */
extern	RasterBlock far *G_ptrFond     ;
extern  RasterBlock far *G_ptrMenu[NOMBRE_CHOIX+1] ;  /* choix pour le menu general */

extern	MouseCursor G_curseurSouris[NOMBRE_COULEUR+1] ;  /* curseur de la souris */

extern  char	    G_etatCurseur        ; /* curseur visible ou curseur masque ? */

extern  int         G_sourisX, G_sourisY ; /* coordonnees de la souris */
extern  int	    G_sourisBouton       ; /* bouton de la souris */

extern  char        G_board[10][10]    ; /* damier du jeu 8x8 avec bordure */
extern  char        G_boardMem[10][10] ; /* damier du jeu pour memoire     */

extern  int         G_joueurCourant    ; /* joueur courant */
extern  int	    G_ordinateur       ; /* ordinateur */

extern  long	    G_appel            ; /* nombre d'appel recursif */

extern  char	    G_choixTypeJeu[2]  ; /* type de jeu choisi par l'utilisateur */
extern  char        G_objetGraphique   ; /* init objet graphique ? */

extern  char        G_version[15]      ; /* version du jeu */


/***** Memorisation du jeu ******/

extern  typeStructureStatistique G_statistique[NOMBRE_COULEUR+1]; /* statistique du jeu */

extern  typeStructureJeu         G_jeu[NOMBRE_COUPS+1]; /* tous les coups du jeu */

extern  char        G_jeuIndiceMax     ; /* indice dans G_jeu du dernier coup */
extern  char        G_jeuIndiceCrt     ; /* indice dans G_jeu du coup en cours */


/***** Saisie *****/

extern  char	    G_saisieEnCours;   /* Flag indiquant une saisie autorisee */
extern  typeStructureSaisie  G_saisie; /* structure pour la saisie */

extern  char        G_nom[NOMBRE_COULEUR+1][15];
extern  char        G_nomMemorise[NOMBRE_COULEUR+1][15];

extern  char	    G_reprise;         /* reprise d'une partie sauvegardee */
extern  char        G_memoriseNomPartie[15];


/***** High Scores *****/

extern char G_memoriseNiveau; /* Dernier niveau affecte pour les meilleurs scores */
extern char G_memoriseRang;   /* Dernier rang affecte pour les meilleurs scores */

extern typeStructureHighScore	G_highScore[6][5]; /* High scores : 6 niveaux, 5 rangs par niveaux */
						   /* niveaux : humain vs humain */
						   /*           initiation       */
						   /*           debutant         */
						   /*           intermediaire    */
						   /*           confirme         */
						   /*           expert           */


/***** Ouvertures *****/

extern typeStructureOuverture G_ouverture[28]; /* ouvertures pour l'affichage courant */
extern char G_selectionCrtEcran; /* selection courante de l'ecran */
extern char G_selectionMaxEcran; /* selection max de l'ecran */
extern char G_pageOuverture;  /* Page de des ouvertures courantes */

/***** Gestion des temps de jeu *****/
extern char G_gestionTemps; /* flag pour provoquer la gestion du temps */
extern time_t G_tempsCourant;
extern time_t G_temps[NOMBRE_COULEUR+1];


/* Variable d'arret recherche en profondeur */
extern char G_stopAlphaBeta;
extern char G_autoriseArret;

/* Variable d'autorisation d'arret de l'application */
extern char G_autoriseArretApplication;

/* Variable precisant si l'ecriture est possible sur le support courant */
extern char G_protectionEcriture;