#include <string.h>
#include <ctype.h>
#include <conio.h>

#include "include\global.h"
#include "include\prototyp.h"
#include "include\dialogue.h"
#include "include\couleur.h"
#include "include\keyboard.h"


/*************************************************************************/
/* Nom : dialogue_boite                                                  */
/*                                                                       */
/* Role : Fonction permettant de dessiner une boite 3D                   */
/*                                                                       */
/*                                                                       */
/* Entree : x1, y1 : coordonnees superieures gauche de la boite          */
/*          x2, y2 : coordonnees inferieures droite de la boite          */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/02/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_boite ( int x1, int y1, int x2, int y2 )
{

	/* dessin de la boite */
	/*                    */
	/* x1,y1              */
	/*	+---+         */
	/*      |   |         */
	/*      +---+         */
	/*           x2,y2    */

	drwfillbox(1, FOND, x1, y1, x2, y2);

	/* contour pour obtenir un effet 3D */

	/* dessin des droites exterieures */
	/*                    */
	/* +----              */
	/* |                  */

	drwline(1, BORD1, x1, y2, x1, y1);
	drwline(1, BORD1, x1, y1, x2, y1);

	/* dessin des droites exterieures */
	/*                    */
	/*     |              */
	/* ----+              */

	drwline(1, BORD2, x1, y2, x2, y2);
	drwline(1, BORD2, x2, y2, x2, y1);

	/* dessin des droites interieures */
	/*                    */
	/* +----              */
	/* |                  */

	drwline(1, BORD2, x1+2, y2-2, x1+2, y1+2);
	drwline(1, BORD2, x1+2, y1+2, x2-2, y1+2);

	/* dessin des droites interieures */
	/*                    */
	/*     |              */
	/* ----+              */

	drwline(1, BORD1, x1+2, y2-2, x2-2, y2-2);
	drwline(1, BORD1, x2-2, y2-2, x2-2, y1+2);
}

/*************************************************************************/
/* Nom : dialogue_cadre                                                  */
/*                                                                       */
/* Role : Fonction permettant de dessiner un cadre 3D                    */
/*                                                                       */
/*                                                                       */
/* Entree : x1, y1 : coordonnees superieures gauche du cadre             */
/*          x2, y2 : coordonnees inferieures droite du cadre             */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_cadre ( int x1, int y1, int x2, int y2 )
{

	/* dessin du cadre    */
	/*                    */
	/* x1,y1              */
	/*	+---+         */
	/*      |   |         */
	/*      +---+         */
	/*           x2,y2    */

	drwbox(1, BORD2, x1, y1, x2, y2);

	/* contour pour obtenir un effet 3D */

	/* dessin des droites interieures */
	/*                    */
	/* +----              */
	/* |                  */

	drwline(1, BORD1, x1+1, y1+1, x2-1, y1+1);
	drwline(1, BORD1, x1+1, y1+1, x1+1, y2-1);

	/* dessin des droites exterieures */
	/*                    */
	/*     |              */
	/* ----+              */

	drwline(1, BORD1, x2+1, y1  , x2+1, y2+1);
	drwline(1, BORD1, x1  , y2+1, x2+1, y2+1);

}

/*************************************************************************/
/* Nom : dialogue_zone_saisie                                            */
/*                                                                       */
/* Role : Fonction permettant de dessiner une zone de saisie             */
/*                                                                       */
/*                                                                       */
/* Entree : x1, y1 : coordonnees superieures gauche du cadre             */
/*          nombreCaractere  : taille en caractere de la zone            */
/*          nombreLigne      : taille en caractere de la zone            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/05/1997 | Ajout parametre nombreLigne pour le besoin de la   */
/*     |            | gestion des ouvertures                             */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_zone_saisie ( int x1, int y1, int nombreCaractere, int nombreLigne )
{

	int x2, y2;

	x2 = x1 + (nombreCaractere) * 8;
	y2 = y1 + (nombreLigne)     * 13;

	/* dessin du fond     */
	/*                    */
	/* x1,y1              */
	/*	+---+         */
	/*      |   |         */
	/*      +---+         */
	/*           x2,y2    */

	drwfillbox(1, TEXTE_FOND, x1, y1, x2, y2);

	/* contour pour obtenir un effet 3D */


	/* dessin des droites exterieurs */
	/*                    */
	/* +----              */
	/* |                  */

	drwline(1, BORD2, x1-2, y1-2, x2+2, y1-2);
	drwline(1, BORD2, x1-2, y1-2, x1-2, y2+1);

	/* dessin des droites interieures */
	/*                    */
	/* +----              */
	/* |                  */

	drwline(1, BORD3, x1-1, y1-1, x2+1, y1-1);
	drwline(1, BORD3, x1-1, y1-1, x1-1, y2+1);

	/* dessin des droites exterieures */
	/*                    */
	/*     |              */
	/* ----+              */

	drwline(1, BORD1, x1-2, y2+2, x2+2, y2+2);
	drwline(1, BORD1, x2+2, y2+2, x2+2, y1-1);

	/* dessin des droites interieures */
	/*                    */
	/*     |              */
	/* ----+              */

	drwline(1, FOND, x1  , y2+1, x2+1, y2+1);
	drwline(1, FOND, x2+1, y2+1, x2+1, y1);

}

/*************************************************************************/
/* Nom : dialogue_bouton_relache                                         */
/*                                                                       */
/* Role : Fonction permettant de dessiner un bouton relache              */
/*                                                                       */
/*                                                                       */
/* Entree : x, y    : coordonnees superieures gauche du bouton           */
/*          tailleX,                                                     */
/*          tailleY : taille du bouton                                   */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 31/03/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_bouton_relache ( int x, int y, int tailleX, int tailleY )
{
	/* Raz de la zone */

	drwfillbox (1, FOND, x-2, y-2, x+tailleX+2, y+tailleY+2);

	/* Dessin du bouton */

	drwline(1, BORD1, x-1        , y-1        , x-1        , y+tailleY+1);
	drwline(1, BORD1, x-1        , y-1        , x+tailleX+1, y-1        );

	drwline(1, BORD2, x+tailleX+1, y          , x+tailleX+1, y+tailleY+1);
	drwline(1, BORD2, x          , y+tailleY+1, x+tailleX+1, y+tailleY+1);

	drwline(1, BORD3, x+tailleX+2,         y-1, x+tailleX+2, y+tailleY+2);
	drwline(1, BORD3, x-1        , y+tailleY+2, x+tailleX+2, y+tailleY+2);

}


/*************************************************************************/
/* Nom : dialogue_bouton_appuye                                          */
/*                                                                       */
/* Role : Fonction permettant de dessiner un bouton appuye               */
/*                                                                       */
/*                                                                       */
/* Entree : x, y    : coordonnees superieures gauche du bouton           */
/*          tailleX,                                                     */
/*          tailleY : taille du bouton                                   */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 31/03/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_bouton_appuye ( int x, int y, int tailleX, int tailleY )
{
	/* Raz de la zone */

	drwfillbox (1, FOND, x-2, y-2, x+tailleX+2, y+tailleY+2);

	/* Dessin du bouton */

	drwline(1, BORD3, x-1        , y-1        , x-1         , y+tailleY+2);
	drwline(1, BORD3, x-1        , y-1        , x+tailleX+1 , y-1        );

	drwline(1, BORD2, x          , y          , x+tailleX+1 , y          );
	drwline(1, BORD2, x          , y          , x           , y+tailleY+1);

	drwline(1, BORD1, x+tailleX+2, y-1        , x+tailleX+2 , y+tailleY+2);
	drwline(1, BORD1, x-1        , y+tailleY+2, x+tailleX+2 , y+tailleY+2);

}


/*************************************************************************/
/* Nom : dialogue_OK                                                     */
/*                                                                       */
/* Role : Fonction permettant de dessiner et gerer le bouton OK          */
/*                                                                       */
/*                                                                       */
/* Entree : x1, y1 : coordonnees superieures gauche du bouton OK         */
/*          x2, y2 : coordonnees inferieures droite du bouton OK         */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/02/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Suppression gestion saisie clavier                 */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_OK ( int okX1, int okY1, int okX2, int okY2 )
{
	char clicOK = FALSE; /* aucun clic sur le bouton OK */


	while (!clicOK)
	{
		/* Dessin du bouton relache */

		dialogue_bouton_relache(okX1, okY1, (okX2-okX1), (okY2-okY1));

		/* Cadre bouton OK */

		drwstring(1, TEXTE, FOND, "OK", okX1 + (okX2 - okX1 - 16) / 2, okY1 + (okY2 - okY1 - 12) / 2);

		/* attente d'un clic de la souris */
		mouse_attente();

		/* effet bouton enfonce */

		if (G_sourisX > okX1 &&
		    G_sourisX < okX2 &&
		    G_sourisY > okY1 &&
		    G_sourisY < okY2)
		{
			dialogue_bouton_appuye(okX1, okY1, (okX2-okX1), (okY2-okY1));
			drwstring(1, TEXTE, FOND, "OK", okX1 + (okX2 - okX1 - 16) / 2, okY1 + (okY2 - okY1 - 12) / 2);
		}

		/* attente d'un relache bouton */
		mouse_attente_relache();

		if (G_sourisX > okX1 &&
		    G_sourisX < okX2 &&
		    G_sourisY > okY1 &&
		    G_sourisY < okY2)
			clicOK = TRUE;
	}
}


/*************************************************************************/
/* Nom : dialogue                                                        */
/*                                                                       */
/* Role : Fonction permettant d'afficher un message a l'ecran            */
/*                                                                       */
/*                                                                       */
/* Entree : message : pointeur sur le message                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/02/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


void dialogue ( char *message )
{
	char ptrLigne[3][25]; /* lignes de la boite de dialogue */
	int caractere, ligne; /* compteur de ligne et de caractere */


	/* La boite de dialogue affiche au maximum 3 lignes */
	/* on positionne un caractere nul en debut ligne    */
	/* au cas ou l'on utilisera pas toutes les lignes   */
	ptrLigne[0][0] = 0x00;
	ptrLigne[1][0] = 0x00;
	ptrLigne[2][0] = 0x00;

	/* Affichage du message sur plusieurs lignes si cela est necessaire */
	ligne = 0;
	caractere = 0;

	while (message[(caractere + 24*ligne)]) /* tant qu'il y a des caracteres */
	{
		ptrLigne[ligne][caractere] = message[(caractere + 24*ligne)];

		caractere++;

		/* passage a la ligne suivante */
		if (caractere == 24)
		{
			ptrLigne[ligne][caractere] = 0x00; /* fin de ligne */

			ligne++;
			caractere = 0;
		}
	}
	ptrLigne[ligne][caractere] = 0x00; /* fin de ligne */


	/* memorisation de la zone d'ecran ou l'on affiche le message */
	blkget(220, 190, 419, 289, G_ptrFond);

	/* dessin de la boite de dialogue avec effet 3D */
	dialogue_boite(220, 190, 419, 289);

	/* Ecriture du message */
	drwstring(1, TEXTE, FOND, ptrLigne[0], 225, 210); /* 1ere ligne */
	drwstring(1, TEXTE, FOND, ptrLigne[1], 225, 225); /* 2eme ligne */
	drwstring(1, TEXTE, FOND, ptrLigne[2], 225, 240); /* 3eme ligne */

	/* bouton OK et attente d'un clic sur le bouton OK */
	dialogue_OK(295, 260, 345, 280);

	/* on restaure la zone d'origine */
	blkput(1, 220, 190, G_ptrFond);
}

/*************************************************************************/
/* Nom : dialogue_type_jeu                                               */
/*                                                                       */
/* Role : Fonction permettant d'afficher le dialogue type jeu            */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

char dialogue_type_jeu ( void )
{
	int i, j; /* variables de boucle */
	char bouton; /* bouton OK ou annuler ? */

	/* dessin du cadre */
	dialogue_boite(coordonneesLibelles[0].x - 5,
		       coordonneesLibelles[0].y - 50,
		       coordonneesBouton[NOMBRE_TYPE-2][1].x + 25,
		       coordonneesBouton[NOMBRE_TYPE-2][1].y + 80 );

	/* Message */
	drwstring(1, TEXTE, FOND, "Choisissez votre type de jeu :", POSITION_X, POSITION_Y-45);

	/* initialisation du cadre */
	for ( i = 0; i < NOMBRE_TYPE; i++)
	{
		drwstring(1,
			  TEXTE,
			  FOND,
			  libellesTypeJeu[i],
			  coordonneesLibelles[i].x,
			  coordonneesLibelles[i].y);

		for ( j = 0; ((j < 2) && ( i < NOMBRE_TYPE-1)); j++)
		{
			if (boutonChoisie[i][j])
				dialogue_bouton_appuye(coordonneesBouton[i][j].x,
						       coordonneesBouton[i][j].y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);
			else
				dialogue_bouton_relache(coordonneesBouton[i][j].x,
						       coordonneesBouton[i][j].y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);
		}
	}

	/* choix reprise d'une partie sauvegardee */
	drwstring(1,
		  TEXTE,
		  FOND,
		  libellesReprise,
		  coordonneesLibelles[NOMBRE_TYPE-1].x,
		  coordonneesLibelles[NOMBRE_TYPE-1].y+30);

	dialogue_bouton_relache(coordonneesReprise.x,
				coordonneesReprise.y,
				TAILLE_BOUTON,
				TAILLE_BOUTON);

	G_reprise = FALSE; /* bouton relache */


	/* Affichage du pion couleur NOIR */
	spritegap(44,
		  coordonneesBouton[0][0].x - 17,
		  coordonneesBouton[0][0].y - 45,
		  G_ptrPionJeu[NOIR],
		  G_ptrPion);

	/* Affichage du pion couleur BLANC */
	spritegap(44,
		  coordonneesBouton[0][1].x - 17,
		  coordonneesBouton[0][1].y - 45,
		  G_ptrPionJeu[BLANC],
		  G_ptrPion);


	/* Affichage du bouton OK */
	dialogue_bouton_relache(POSITION_X+100,
				coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
				50,
				20);

	drwstring(1,
		  TEXTE,
		  FOND,
		  "OK",
		  POSITION_X+100+17,
		  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);


	/* Affichage du bouton Annuler */
	dialogue_bouton_relache(POSITION_X+170,
				coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
				62,
				20);

	drwstring(1,
		  TEXTE,
		  FOND,
		  "Annuler",
		  POSITION_X+170+3,
		  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);

	/* Affichage dans la zone d'aide en ligne */
	dialogue_aide_en_ligne("Utilisez la souris pour faire votre choix.");

	/* on appelle la procedure gerant les boutons du dialogue */
	bouton = dialogue_gere_choix();

	if (bouton == OK)
	{
		/* on valide le choix */
		G_choixTypeJeu[0] = choixCourant[0];
		G_choixTypeJeu[1] = choixCourant[1];

		return (TRUE);
	}
	else
		return (FALSE);



}

/*************************************************************************/
/* Nom : dialogue_gere_choix                                             */
/*                                                                       */
/* Role : Fonction permettant de gerer le choix de l'utilisateur         */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 27/04/1997 | Connexion du bouton reprise                        */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Modification des libelles des boutons OK et Annuler*/
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

char dialogue_gere_choix( void )
{
	char clicOkAnnuler = FALSE; /* clic sur le bouton annuler ou OK */
	int  i, j, k; /* variables de boucle */

	int  blancVersBlanc[8] = { BLANC_OVALE, NOIR_BLANC, NOIR_OVALE, NOIR,
				   NOIR_OVALE, BLANC_NOIR, BLANC_OVALE, BLANC };
	int  noirVersNoir  [8] = { NOIR_OVALE, BLANC_NOIR, BLANC_OVALE, BLANC,
				   BLANC_OVALE, NOIR_BLANC, NOIR_OVALE, NOIR};

	char bouton = ANNULER; /* bouton par defaut sur annuler */


	while (!clicOkAnnuler)
	{

		/* etat courant des differents bouton */
		dialogue_etat_choix();

		/* bouton OK */
		dialogue_bouton_relache(POSITION_X+100,
				       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
				       50,
				       20);
		/* bouton Annuler */
		dialogue_bouton_relache(POSITION_X+170,
				       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
				       62,
				       20);
		/* texte OK */
		drwstring(1,
			  TEXTE,
			  FOND,
			  "Jouer",
			  POSITION_X+89+17,
			  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);

		/* texte Annuler */
		drwstring(1,
			  TEXTE,
			  FOND,
			  "Sortir",
			  POSITION_X+174+3,
			  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);

		/* bouton reprise */
		if (G_reprise == TRUE)
			dialogue_bouton_appuye (coordonneesReprise.x,
						coordonneesReprise.y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
		else
			dialogue_bouton_relache(coordonneesReprise.x,
						coordonneesReprise.y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);

		/*******************************************/
		/* on attend un appuye bouton de la souris */
		/*******************************************/
		mouse_attente();

		/* effet appuye bouton */

		/* Bouton choix ? */
		for (i=0; i < NOMBRE_TYPE-1; i++)
		{
			for (j=0; j < 2; j++)
			{
				if (mouse_zone(coordonneesBouton[i][j].x-2,
					       coordonneesBouton[i][j].x+TAILLE_BOUTON+2,
					       coordonneesBouton[i][j].y-2,
					       coordonneesBouton[i][j].y+TAILLE_BOUTON+2))

				{
					dialogue_bouton_appuye(coordonneesBouton[i][j].x,
							       coordonneesBouton[i][j].y,
							       TAILLE_BOUTON,
							       TAILLE_BOUTON);

					/* le choix courant est relache */
					dialogue_bouton_relache(coordonneesBouton[choixCourant[j]][j].x,
								coordonneesBouton[choixCourant[j]][j].y,
								TAILLE_BOUTON,
								TAILLE_BOUTON);
				}
			}
		}

		/* Bouton reprise ? */
		if (mouse_zone(coordonneesReprise.x-2,
			       coordonneesReprise.x+TAILLE_BOUTON+2,
			       coordonneesReprise.y-2,
			       coordonneesReprise.y+TAILLE_BOUTON+2))
			if (G_reprise == TRUE)
				dialogue_bouton_relache(coordonneesReprise.x,
						       coordonneesReprise.y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);
			else
				dialogue_bouton_appuye (coordonneesReprise.x,
						       coordonneesReprise.y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);

		/* Bouton OK */
		if (mouse_zone(POSITION_X+100,
			       POSITION_X+150,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+70))
		{

			dialogue_bouton_appuye(POSITION_X+100,
					       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
					       50,
					       20);
			/* texte OK */
			drwstring(1,
				  TEXTE,
				  FOND,
				  "Jouer",
				  POSITION_X+89+17,
				  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);
		}

		/* Bouton Annule */
		if (mouse_zone(POSITION_X+170,
			       POSITION_X+232,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+70))
		{

			dialogue_bouton_appuye(POSITION_X+170,
					       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
					       62,
					       20);

			/* texte Annuler */
			drwstring(1,
				  TEXTE,
				  FOND,
				  "Sortir",
				  POSITION_X+174+3,
				  coordonneesBouton[NOMBRE_TYPE-2][0].y+50+4);
		}

		/*****************************/
		/* attente du relache bouton */
		/*****************************/
		mouse_attente_relache();

		/* Bouton choix ? */
		for (i=0; i < NOMBRE_TYPE-1; i++)
		{
			for (j=0; j < 2; j++)
			{
				if (mouse_zone(coordonneesBouton[i][j].x-2,
					       coordonneesBouton[i][j].x+TAILLE_BOUTON+2,
					       coordonneesBouton[i][j].y-2,
					       coordonneesBouton[i][j].y+TAILLE_BOUTON+2))

				{
					/* Effet si changement de choix */
					if (choixCourant[j] != i)
					{
						for (k=0; k < 8; k++)
						{
							if (j==0)
							{

								/* Affichage NOIR */
								drwfillbox(1,
									   FOND,
									   coordonneesBouton[0][0].x - 17,
									   coordonneesBouton[0][0].y - 45,
									   coordonneesBouton[0][0].x - 17+38,
									   coordonneesBouton[0][0].y - 45+40);

								spritegap(44,
									  coordonneesBouton[0][0].x - 17,
									  coordonneesBouton[0][0].y - 45,
									  G_ptrPionJeu[noirVersNoir[k]],
									  G_ptrPion);
							}
							else
							{

								/* Affichage BLANC */
								drwfillbox(1,
									   FOND,
									   coordonneesBouton[0][1].x - 17,
									   coordonneesBouton[0][1].y - 45,
									   coordonneesBouton[0][1].x - 17+38,
									   coordonneesBouton[0][1].y - 45+40);

								spritegap(44,
									  coordonneesBouton[0][1].x - 17,
									  coordonneesBouton[0][1].y - 45,
									  G_ptrPionJeu[blancVersBlanc[k]],
									  G_ptrPion);
							}
							delay(50);

						}


					}
					/* on invalide le choix precedent */
					boutonChoisie[choixCourant[j]][j] = FALSE;

					/* le choix courant est valide */
					boutonChoisie[i][j] = TRUE;

					/* on memorise le choix */
					choixCourant[j] = i;
				}
			}
		}

		/* Bouton OK */
		if (mouse_zone(POSITION_X+100,
			       POSITION_X+150,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+70))
		{
			bouton = OK;

			clicOkAnnuler = TRUE;
		}

		/* Bouton Annuler */
		if (mouse_zone(POSITION_X+170,
			       POSITION_X+232,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+50,
			       coordonneesBouton[NOMBRE_TYPE-2][0].y+70))
		{
			bouton = ANNULER;

			clicOkAnnuler = TRUE;
		}

		/* Bouton reprise ? */
		if (mouse_zone(coordonneesReprise.x-2,
			       coordonneesReprise.x+TAILLE_BOUTON+2,
			       coordonneesReprise.y-2,
			       coordonneesReprise.y+TAILLE_BOUTON+2))
			if (G_reprise == TRUE)
				G_reprise = FALSE;
			else
				G_reprise = TRUE;

	}

	/* on envoie le bouton appuyee */

	return (bouton);

}

/*************************************************************************/
/* Nom : dialogue_etat_choix                                             */
/*                                                                       */
/* Role : Fonction permettant d'afficher l'etat des boutons en fonction  */
/*        du choix de l'utilisateur                                      */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void dialogue_etat_choix ( void )
{
	int  i, j; /* variables de boucle */

	for ( i = 0; i < NOMBRE_TYPE; i++)
	{
		for ( j = 0; ((j < 2) && ( i < NOMBRE_TYPE-1)); j++)
		{
			if (boutonChoisie[i][j])
				dialogue_bouton_appuye(coordonneesBouton[i][j].x,
						       coordonneesBouton[i][j].y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);
			else
				dialogue_bouton_relache(coordonneesBouton[i][j].x,
						       coordonneesBouton[i][j].y,
						       TAILLE_BOUTON,
						       TAILLE_BOUTON);
		}
	}

}

/*************************************************************************/
/* Nom : dialogue_aide_en_ligne                                          */
/*                                                                       */
/* Role : Fonction permettant d'afficher un message dans l'aide en ligne */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 16/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


void dialogue_aide_en_ligne ( char *message )
{
	char ligneBlanche[46];

	memset(ligneBlanche, ' ', sizeof(ligneBlanche));
	ligneBlanche[45] = '\0';

	/* on efface la ligne */
	drwstring(1, TEXTE, FOND, ligneBlanche, 140, 454);

	/* on affiche le message */
	drwstring(1, TEXTE, FOND, message, 140, 454);

}

/*************************************************************************/
/* Nom : dialogue_choix_couleur                                          */
/*                                                                       */
/* Role : Fonction permettant de selectionner la couleur                 */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : couleur selectionnee par l'utilisateur (NOIR ou BLANC)       */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


int dialogue_choix_couleur ( void )
{
	int couleur; /* couleur choisie */


	/* memorisation de la zone d'ecran ou l'on affiche le message */
	blkget(220, 190, 419, 289, G_ptrFond);

	/* dessin de la boite de dialogue avec effet 3D */
	dialogue_boite(220, 190, 419, 289);

	/* Message */
	drwstring(1, TEXTE, FOND, "Choisissez votre couleur", 225, 200);

	drwstring(1, TEXTE, FOND, "Noir........", 240, 220);
	drwstring(1, TEXTE, FOND, "Blanc.......", 240, 235);

	/* bouton OK et attente d'un clic sur le bouton OK apres choix utilisateur */
	couleur = dialogue_OK_couleur(295, 260, 345, 280);

	/* on restaure la zone d'origine */
	blkput(1, 220, 190, G_ptrFond);

	return couleur;
}

/*************************************************************************/
/* Nom : dialogue_OK_couleur                                             */
/*                                                                       */
/* Role : Fonction permettant de dessiner, gerer les bouton OK et les    */
/*        choix de la couleur                                            */
/*                                                                       */
/* Entree : x1, y1 : coordonnees superieures gauche du bouton OK         */
/*          x2, y2 : coordonnees inferieures droite du bouton OK         */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

int dialogue_OK_couleur ( int okX1, int okY1, int okX2, int okY2 )
{
	char clicOK = FALSE; /* aucun clic sur le bouton OK */

	int couleur = NOIR; /* couleur par defaut */


	while (!clicOK)
	{
		/* Dessin du bouton OK relache */
		dialogue_bouton_relache(okX1, okY1, (okX2-okX1), (okY2-okY1));

		/* Texte bouton OK */
		drwstring(1, TEXTE, FOND, "OK", okX1 + (okX2 - okX1 - 16) / 2, okY1 + (okY2 - okY1 - 12) / 2);

		/* Bouton couleurs */
		if ( couleur == NOIR )
		{
			dialogue_bouton_appuye (coordonneesCouleur[NOIR].x,
						coordonneesCouleur[NOIR].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
			dialogue_bouton_relache(coordonneesCouleur[BLANC].x,
						coordonneesCouleur[BLANC].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
		}
		else
		{
			dialogue_bouton_relache(coordonneesCouleur[NOIR].x,
						coordonneesCouleur[NOIR].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
			dialogue_bouton_appuye (coordonneesCouleur[BLANC].x,
						coordonneesCouleur[BLANC].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
		}


		/**********************************/
		/* attente d'un clic de la souris */
		/**********************************/
		mouse_attente();

		/************************/
		/* effet bouton enfonce */
		/************************/

		/* bouton OK */
		if (mouse_zone(okX1, okX2, okY1, okY2))
		{
			dialogue_bouton_appuye(okX1, okY1, (okX2-okX1), (okY2-okY1));
			drwstring(1, TEXTE, FOND, "OK", okX1 + (okX2 - okX1 - 16) / 2, okY1 + (okY2 - okY1 - 12) / 2);
		}

		/* bouton NOIR */
		if (mouse_zone(coordonneesCouleur[NOIR].x-2,
			       coordonneesCouleur[NOIR].x+TAILLE_BOUTON+2,
			       coordonneesCouleur[NOIR].y-2,
			       coordonneesCouleur[NOIR].y+TAILLE_BOUTON+2))
		{
			dialogue_bouton_appuye (coordonneesCouleur[NOIR].x,
						coordonneesCouleur[NOIR].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
			dialogue_bouton_relache(coordonneesCouleur[BLANC].x,
						coordonneesCouleur[BLANC].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
		}

		/* bouton BLANC */
		if (mouse_zone(coordonneesCouleur[BLANC].x-2,
			       coordonneesCouleur[BLANC].x+TAILLE_BOUTON+2,
			       coordonneesCouleur[BLANC].y-2,
			       coordonneesCouleur[BLANC].y+TAILLE_BOUTON+2))
		{
			dialogue_bouton_relache(coordonneesCouleur[NOIR].x,
						coordonneesCouleur[NOIR].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
			dialogue_bouton_appuye (coordonneesCouleur[BLANC].x,
						coordonneesCouleur[BLANC].y,
						TAILLE_BOUTON,
						TAILLE_BOUTON);
		}

		/*******************************/
		/* attente d'un relache bouton */
		/*******************************/
		mouse_attente_relache();

		/* bouton OK */
		if (mouse_zone(okX1, okX2, okY1, okY2))
			clicOK = TRUE;

		/* bouton NOIR */
		if (mouse_zone(coordonneesCouleur[NOIR].x-2,
			       coordonneesCouleur[NOIR].x+TAILLE_BOUTON+2,
			       coordonneesCouleur[NOIR].y-2,
			       coordonneesCouleur[NOIR].y+TAILLE_BOUTON+2))

			couleur = NOIR;

		/* bouton BLANC */
		if (mouse_zone(coordonneesCouleur[BLANC].x-2,
			       coordonneesCouleur[BLANC].x+TAILLE_BOUTON+2,
			       coordonneesCouleur[BLANC].y-2,
			       coordonneesCouleur[BLANC].y+TAILLE_BOUTON+2))

			couleur = BLANC;
	}

	return couleur;
}


/*************************************************************************/
/* Nom : dialogue_passe_tour                                             */
/*                                                                       */
/* Role : Affichage indiquant le joueur devant passer son tour           */
/*                                                                       */
/*                                                                       */
/* Entree : couleur : couleur du joueur devant passer son tour           */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/


void dialogue_passe_tour ( int couleur )
{
	/* memorisation de la zone d'ecran ou l'on affiche le message */
	blkget(220, 190, 419, 289, G_ptrFond);

	/* affichage du message */
	dialogue_boite(220, 190, 419, 289);

	drwstring(1, TEXTE, FOND, "Le joueur", 225, 215);

	/* Affichage du pion devant passer son tour */
	spritegap(44, 305, 200, G_ptrPionJeu[couleur], G_ptrPion);

	drwstring(1, TEXTE, FOND, "doit passer son tour", 225, 240);


	/* bouton OK et attente clic sur le bouton OK */
	dialogue_OK(295, 260, 345, 280);

	/* on restaure la zone d'origine */
	blkput(1, 220, 190, G_ptrFond);
}

/*************************************************************************/
/* Nom : dialogue_OK_Annuler                                             */
/*                                                                       */
/* Role : Fonction permettant de dessiner et gerer les boutons OK et     */
/*        Annuler                                                        */
/*                                                                       */
/* Entree : okX, okY : coordonnees superieures gauche du bouton OK       */
/*          annuleX, annuleY : coordonnees superieures gauche du bouton  */
/*                               annuler                                 */
/* Sortie : bouton clique (OK ou ANNULER)                                */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 29/06/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

char dialogue_OK_Annuler ( int okX, int okY, int annuleX, int annuleY )
{
	char clicOK      = FALSE; /* aucun clic sur le bouton OK */
	char clicAnnuler = FALSE; /* aucun clic sur le bouton annuler */

	int tailleOkX, tailleOkY;
	int tailleAnnuleX, tailleAnnuleY;

	char bouton = OK;

	tailleOkX = 6 *  8 + 4;
	tailleOkY =     13 + 4;

	tailleAnnuleX = 7 *  8 + 4;
	tailleAnnuleY =     13 + 4;

	while (!clicOK && !clicAnnuler)
	{
		/* Dessin des boutons relaches */
		dialogue_bouton_relache(okX, okY, tailleOkX, tailleOkY);
		dialogue_bouton_relache(annuleX, annuleY, tailleAnnuleX, tailleAnnuleY);

		/* Texte des boutons OK et Annuler */
		drwstring(1, TEXTE, FOND, "OK", okX + 2 + 16, okY + 2);
		drwstring(1, TEXTE, FOND, "Annuler", annuleX + 2, annuleY + 2);

		/* attente d'un clic de la souris */
		mouse_attente();

		/* saisie en cours ? */
		if (G_saisieEnCours && iskey()) /* pas de clic mais appui clavier */
		{

			clicOK = dialogue_gestion_clavier();

			if (clicOK == TRUE)
				bouton = OK;
		}
		else
		{

			/* effet bouton enfonce */

			/* Bouton OK */
			if (mouse_zone(okX, okX + tailleOkX, okY, okY + tailleOkY))
			{
				dialogue_bouton_appuye(okX, okY, tailleOkX, tailleOkY);
				drwstring(1, TEXTE, FOND, "OK", okX + 2 + 16, okY + 2);
			}

			/* Bouton Annuler */
			if (mouse_zone(annuleX, annuleX + tailleAnnuleX, annuleY, annuleY + tailleAnnuleY))
			{
				dialogue_bouton_appuye(annuleX, annuleY, tailleAnnuleX, tailleAnnuleY);
				drwstring(1, TEXTE, FOND, "Annuler", annuleX + 2, annuleY + 2);
			}

			/* attente d'un relache bouton */
			mouse_attente_relache();

			if (mouse_zone(okX, okX + tailleOkX, okY, okY + tailleOkY))
			{
				clicOK = TRUE;
				bouton = OK;
			}

			if (mouse_zone(annuleX, annuleX + tailleAnnuleX, annuleY, annuleY + tailleAnnuleY))
			{
				clicAnnuler = TRUE;
				bouton = ANNULER;
			}
		}
	}

	return bouton;
}


/*************************************************************************/
/* Nom : dialogue_saisie                                                 */
/*                                                                       */
/* Role : Fonction permettant de saisir une chaine                       */
/*                                                                       */
/*                                                                       */
/* Entree : message      : message a afficher pour demander la saisie    */
/*          nombreCarMax : nombre de caractere max autorise              */
/*                                                                       */
/* Sortie : bouton clique (OK ou ANNULER)                                */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 29/06/1997 | La zone de saisie peut tre pre-rensigne           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


char dialogue_saisie ( char *message, char *preRenseigne, char nombreCarMax )
{
	char taille;
	char bouton;

	/* memorisation de la zone d'ecran ou l'on affiche le message */
	blkget(220, 190, 419, 289, G_ptrFond);

	/* dessin de la boite de dialogue avec effet 3D */
	dialogue_boite(220, 190, 419, 289);

	/* Ecriture du message */
	drwstring(1, TEXTE, FOND, message, 225, 210); /* Ligne message */

	/* Zone de saisie */
	dialogue_zone_saisie (230, 230, nombreCarMax, 1);

	/* preparation de la saisie */
	G_saisieEnCours = TRUE;


	taille = strlen(preRenseigne);

	/* pas de pre renseignement de la zone de saisie */
	if ( taille == 0 )
	{
		G_saisie.chaine[0] = 0x00; /* chaine vide */
		G_saisie.indiceCrt = 0;
	}
	else /* pre renseignement de la zone de saisie */
	{
		strcpy(G_saisie.chaine, preRenseigne);

		G_saisie.chaine[taille] = 0x00;

		/* test sur la taille du champ pre renseigne */
		if ( taille > nombreCarMax)
			G_saisie.indiceCrt = nombreCarMax;
		else
			G_saisie.indiceCrt = taille;

		/* affichage de la chaine courante */
		drwstring(1, TEXTE, TEXTE_FOND, G_saisie.chaine, 231, 230);
	}

	G_saisie.indiceMax = nombreCarMax;

	/* vidage du buffer clavier */
	while(kbhit()) getch();

	/* bouton OK et Annuler d'un clic sur l'un des deux boutons */

	bouton = dialogue_OK_Annuler(254, 260, 326, 260);

	G_saisieEnCours = FALSE;

	/* on restaure la zone d'origine */

	blkput(1, 220, 190, G_ptrFond);

	/* Renvoie du bouton sur lequel l'utilisateur a clique */
	return bouton;
}

/*************************************************************************/
/* Nom : dialogue_gestion_clavier                                        */
/*                                                                       */
/* Role : Fonction permettant de gerer un appui clavier                  */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/*                                                                       */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


char dialogue_gestion_clavier ( void )
{
	int  toucheClavier =  0   ; /* valeur de la touche du clavier */
	char buffer[] = "                        ";


	/* On positionne la taille du buffer a la taille max de la saisie */
	buffer[G_saisie.indiceMax] = 0x00;

	/* on lit la touche frappee */
	toucheClavier = getkey();

	if (toucheClavier > 0)
	{
		/* appui sur touche Return */
		if (toucheClavier == RETURN)
				return TRUE;

		/* appui sur Backspace */
		else if (toucheClavier == BS && G_saisie.indiceCrt > 0)
		{
			G_saisie.indiceCrt--;
			G_saisie.chaine[G_saisie.indiceCrt] = 0x00;
		}

		/* appui sur un caractere alphanumerique */
		else if   ((isalpha(toucheClavier) || isdigit(toucheClavier))
			&& (G_saisie.indiceCrt < G_saisie.indiceMax))
		{
			G_saisie.chaine[G_saisie.indiceCrt++] = toucheClavier;
			G_saisie.chaine[G_saisie.indiceCrt] = 0x00;

		}
		else
		{
			sound(300);
			delay(80);
			nosound();
		}

	}

	/* affichage de la chaine courante */
	drwstring(1, TEXTE, TEXTE_FOND, buffer, 231, 230);
	drwstring(1, TEXTE, TEXTE_FOND, G_saisie.chaine, 231, 230);


	return FALSE;
}
