#include <stdio.h>
#include <dir.h>
#include <string.h>

#include "include\svgacc.h"
#include "include\prototyp.h"
#include "include\global.h"


/*************************************************************************/
/* Nom : sauve_partie                                                    */
/*                                                                       */
/* Role : Fonction permettant de sauvegarder une partie                  */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/05/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/05/1997 | Ajout sauvegarde du type de partie                 */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Ajout sauvegarde des temps de jeu                  */
/*     |            | Ajout de la saisie du nom de fichier               */
/*     |            |                                                    */
/* PDB | 10/08/1997 | Pas de sauvegarde si protection en ecriture active */
/*     |            |                                                    */
/*************************************************************************/


void sauve_partie ( void )
{
	FILE *fichierJeu;        /* fichier de sauvegarde */
	char buffer[MAX_BUFFER]; /* chaine tampon */
	char nomFichier[]        = "othxxxxx";
	char nomFichierComplet[] = "data\\othxxxxx.dat";  /* canevas pour les noms de fichier */
	int  resultat;  	 /* resultat de la recherche d'un nom de fichier */

	char bouton;

	struct ffblk bloc_fichier;

	/* Retour si protection ecriture */
	if (G_protectionEcriture == TRUE)
	{
		return;
	}

	/* saisie du nom et verification de l'existance */
	do
	{
		bouton = dialogue_saisie("Sauver la partie sous", "", 8);

		if (bouton == OK)
		{
			strcpy(nomFichier, G_saisie.chaine);

			sprintf(nomFichierComplet, "data\\%s.dat", nomFichier); /* nom fichier + extension + chemin */

			/* on verifie si ce fichier existe deja */
			resultat = findfirst(nomFichierComplet, &bloc_fichier, 0);

			if (resultat == 0)
			{
				sprintf(buffer, "La partie %-8s      existe dj, changez de nom svp.", nomFichier);
				dialogue(buffer);
			}
		}

	} while (!((bouton == ANNULER) || ((bouton == OK) && (resultat != 0))));

	/* Pas de sauvegarde si clic sur annuler */
	if (bouton == ANNULER)
	{
		return;
	}


	/* on cree le fichier de sauvegarde */
	if ((fichierJeu = fopen(nomFichierComplet, "wb")) == NULL)
	{
		sprintf(buffer, "Impossible de crer %s", nomFichier);
		dialogue(buffer);
		return;
	}

	/* on memorise le nom de la partie */
	strcpy(G_memoriseNomPartie, nomFichier);

	/* sauvegarde type de partie */
	fwrite(G_choixTypeJeu, sizeof(G_choixTypeJeu), 1, fichierJeu);

	/* sauvegarde temps */
	fwrite(G_temps, sizeof(G_temps), 1, fichierJeu);

	/* sauvegarde des noms des joueurs */
	fwrite(G_nom, sizeof(G_nom), 1, fichierJeu);

	/* sauvegarde des indices du jeu */
	fwrite(&G_jeuIndiceMax, sizeof(&G_jeuIndiceMax), 1, fichierJeu);

	/* sauvegardes des coups */
	fwrite(G_jeu, sizeof(G_jeu), 1, fichierJeu);

	fclose(fichierJeu);

//	sprintf(buffer, "Votre partie a ete      sauvegardee sous :      %s", nomFichier);
	sprintf(buffer, "Partie enregistre sous %s", nomFichier);
	dialogue(buffer);
}

/*************************************************************************/
/* Nom : charge_partie                                                   */
/*                                                                       */
/* Role : Fonction permettant de charger une partie                      */
/*                                                                       */
/* Entree : nomFichier : nom du fichier contenant les donnees de la      */
/*                       partie                                          */
/*                                                                       */
/* Sortie : resultat du chargement : OK pour chargement reussi           */
/*                                   NOK pour un probleme de chargement  */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/05/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/05/1997 | Ajout chargement du type de partie                 */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Ajout chargement des temps de jeu                  */
/*     |            |                                                    */
/*************************************************************************/


char charge_partie ( char *nomFichier )
{
	FILE *fichierJeu;
	char buffer[MAX_BUFFER];

	/* on ouvre le fichier */
	if ((fichierJeu = fopen(nomFichier, "rb")) == NULL)
	{
		sprintf(buffer, "Impossible d'ouvrir le  fichier %s", nomFichier);
		dialogue(buffer);
		return NOK;
	}

	/* on se positionne en debut de fichier */
	fseek(fichierJeu, 0, SEEK_SET);

	/* chargement type de partie */
	fread(G_choixTypeJeu, sizeof(G_choixTypeJeu), 1, fichierJeu);

	/* chargement temps */
	fread(G_temps, sizeof(G_temps), 1, fichierJeu);

	/* noms des joueurs */
	fread(G_nom, sizeof(G_nom), 1, fichierJeu);

	/* indices du jeu */
	fread(&G_jeuIndiceMax, sizeof(&G_jeuIndiceMax), 1, fichierJeu);
	G_jeuIndiceCrt = 0;

	/* coups */
	fread(G_jeu, sizeof(G_jeu), 1, fichierJeu);

	fclose(fichierJeu);

	return OK;
}