/*************************************************************************/
/* Nom : jouer                                                           */
/*                                                                       */
/* Role : Fonction permettant de jouer  othello                         */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 24/03/1997 | Prise en compte de la possibilite du retournement  */
/*     |            | des pions                                          */
/*     |            |                                                    */
/* PDB | 30/03/1997 | Modification de l'emplacement initial des pions    */
/*     |            |                                                    */
/* PDB | 06/04/1997 | Dport de l'initialisation du jeu                  */
/*     |            |                                                    */
/* PDB | 27/04/1997 | Appel des fonctions correspondant au type de jeu   */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

#include <dos.h>
#include <conio.h>
#include <stdio.h>
#include <string.h>
#include <mem.h>

#include "include\svgacc.h"

#include "include\prototyp.h"
#include "include\global.h"
#include "include\couleur.h"

void jouer ( int modeJeu )
{
	/* on initialise l'environnement de jeu */
	initialise_ecran_jeu();

	/* on determine le jeu a mettre en place */
	switch (modeJeu)
	{
		case NORMAL:     /* cas normal */
				 jeu_normal();
				 break;

		case INITIATION: /* cas initiation */
				 initiation();
				 break;
	}


	/* effet d'effacement de l'image courante */

	palioauto(G_gifPalette, 0, 255, -50);
}

/*************************************************************************/
/* Nom : initialise_ecran_jeu                                            */
/*                                                                       */
/* Role : Fonction permettant d'initialiser l'ecran du jeu               */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/
void initialise_ecran_jeu ( void )
{
	int i, j; /* varaibles de boucle */
	char buffer[MAX_BUFFER] ;


	/* chargement de l'image */
	sprintf(buffer, "%s", "images\\otho.pcx\0");
	charge_image(buffer, RES640);

	/* on initialise une seule fois les objets graphiques du jeu */
	if (!G_objetGraphique)
	{
		initialise_objet_graphique();

		G_objetGraphique = TRUE; /* initialisation realisee */
	}


	/* derniere preparation sur l'image avant de l'afficher */
//	palioauto(G_gifPalette, 0, 255, -128);

	video_off();

	for (i = 1; i < 9; i++)
		for (j = 1; j < 9; j++)
			jouer_coup(i, j, VIDE);

	video_on();

	/* zone d'aide en ligne */
	dialogue_boite(134, 445, 504, 475);

	/* effet d'affichage progressif */
//	palioauto(G_gifPalette, 0, 255, 10);

}

/*************************************************************************/
/* Nom : initialise_objet_graphique                                      */
/*                                                                       */
/* Role : Fonction permettant d'initialiser les objets graphiques du jeu */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/
void initialise_objet_graphique ( void )
{
	int  nombre;

	/* initialisation des chiffres */

	/* Memorisation de la definition des chiffres dans G_ptrNombre */

	/* chaque chiffre est defini dans une matrice de 20*28 pixels */
	/* chaque chiffre occupe donc 20*28 = 560 octets              */
	/* a cela il faut rajouter 4 octets pour la definition de     */
	/* la taille : 564 <=> TAILLE_CHIFFRE                         */

	/* les chiffres sont disposes de la maniere suivante en x=221 et y=446 */
	/* 0123456789 */
	for ( nombre = 0; nombre < 10 ; nombre++)
	{
		blkget(221+nombre*TAILLE_CHIFFRE_X,
		       446,
		       221+TAILLE_CHIFFRE_X*(nombre+1) - 1,
		       446+TAILLE_CHIFFRE_Y - 1,
		       G_ptrNombre[nombre]);
	}


	/****************************************************************/
	/* memorisation de la definition des differents etats des cases */
	/****************************************************************/

	/* case vide */
	blkget (364, 205, 402, 243, G_ptrPionJeu[VIDE]);

	/* 1er pion - NOIR */
	blkget (321, 205, 359, 243, G_ptrPionJeu[NOIR]);

	/* 2eme pion - BLANC */
	blkget (278, 205, 316, 243, G_ptrPionJeu[BLANC]);

	/* case pion a 90 noir blanc */
	blkget (278, 248, 316, 286, G_ptrPionJeu[NOIR_BLANC]);

	/* case pion a 90 blanc noir */
	blkget (321, 248, 359, 286, G_ptrPionJeu[BLANC_NOIR]);

	/* case pion a 45 noir       */
	blkget (407, 248, 445, 286, G_ptrPionJeu[NOIR_OVALE]);

	/* case pion a 45 blanc      */
	blkget (364, 248, 402, 286, G_ptrPionJeu[BLANC_OVALE]);

}

/*************************************************************************/
/* Nom : initialise_jeu                                                  */
/*                                                                       */
/* Role : Fonction permettant d'initialiser le jeu                       */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 18/04/1997 | Ajout initialisation de G_statistque               */
/*     |            |                                                    */
/* PDB | 19/04/1997 | Ajout initialisation des indices du jeu            */
/*     |            |                                                    */
/* PDB | 26/06/1997 | Ajout initialisation du temps                      */
/*     |            |                                                    */
/*************************************************************************/

void initialise_jeu ( void )
{
	/* Nombre de situation de jeu analysee */
	G_appel = 0;

	/* initialisation du temps effectif de jeu */
	memset(G_temps, 0, sizeof(G_temps));
	
	/* Initialisation statistiques */
	G_statistique[NOIR].score           = 0;
	G_statistique[NOIR].mobilite        = 0;
	G_statistique[NOIR].evaluation      = 0;
	G_statistique[NOIR].nombreFeuilles  = 0;
	G_statistique[NOIR].profondeur      = 0;
	G_statistique[NOIR].coups.x         = 0;
	G_statistique[NOIR].coups.y         = 0;

	G_statistique[BLANC].score          = 0;
	G_statistique[BLANC].mobilite       = 0;
	G_statistique[BLANC].evaluation     = 0;
	G_statistique[BLANC].nombreFeuilles = 0;
	G_statistique[BLANC].profondeur     = 0;
	G_statistique[BLANC].coups.x        = 0;
	G_statistique[BLANC].coups.y        = 0;

	/* Initialisation des indices de la table G_jeu */
	G_jeuIndiceMax = 0;
	G_jeuIndiceCrt = 0;

	/* effacement des cases contenant la definition des pions ovales */
	/* les autres seront effaces lors du positionnement du jeu initial */
	spritegap(255, 407, 248, G_ptrPionJeu[VIDE], G_ptrPion);
	spritegap(255, 364, 248, G_ptrPionJeu[VIDE], G_ptrPion);

	/***************************************************************/
	/* Preparation des tableaux de bords                           */
	/***************************************************************/

	/* tableau de bord principal commande */
	dialogue_boite(152, 5, 487, 50);

	initialise_tableau_commande();

	/* tableau des scores des joueurs NOIR et BLANC */
	dialogue_boite( 10, 60, 120, 430);
	dialogue_boite(520, 60, 630, 430);

	/* cadre des noms des joueurs */
	dialogue_cadre( 20, 70, 110, 90);
	dialogue_cadre(530, 70, 620, 90);


	/* zone d'aide en ligne */
	dialogue_boite(134, 445, 504, 475);

	/* Affichage du pion couleur NOIR dans la premier zone */
	spritegap(44,  44,  70+23, G_ptrPionJeu[NOIR], G_ptrPion);

	/* Affichage du pion couleur BLANC dans la deuxieme zone */
	spritegap(44, 554,  70+23, G_ptrPionJeu[BLANC], G_ptrPion);

	/* Affichage du joueur courant dans la zone determinant */
	/* le tour du joueur */
	spritegap (44,
		   300,
		    10,
		   G_ptrPionJeu[NOIR],
		   G_ptrPion);

	/* on initialise le damier courant et le damier tampon */
	memset(G_board   , VIDE, 100); /* damier 10*10 = 100 */
	memset(G_boardMem, VIDE, 100); /* damier 10*10 = 100 */


	/* on place les pions pour le debut du jeu */
	/*  abcdefgh */
	/* 1         */
	/* 2         */
	/* 3         */
	/* 4   ox    */
	/* 5   xo    */
	/* 6         */
	/* 7         */
	/* 8         */
	/*           */
	/* Avec x : NOIR    o : BLANC */

	jouer_coup(4, 4, BLANC);
	jouer_coup(4, 5, NOIR);
	jouer_coup(5, 5, BLANC);
	jouer_coup(5, 4, NOIR);

	/* affichage du nombre de pion a l'ecran */
	compte_pions();

	/* affichage des pions sur le damier */
	affiche_pions();


	/* Memorisation du jeu courant */
	memcpy(G_jeu[G_jeuIndiceCrt].damier, G_board, 100);

	G_jeu[G_jeuIndiceCrt].couleur = VIDE;

	G_jeu[G_jeuIndiceCrt].statistique.score          = 0;
	G_jeu[G_jeuIndiceCrt].statistique.mobilite       = 0;
	G_jeu[G_jeuIndiceCrt].statistique.evaluation     = 0;
	G_jeu[G_jeuIndiceCrt].statistique.nombreFeuilles = 0;
	G_jeu[G_jeuIndiceCrt].statistique.profondeur     = 0;
	G_jeu[G_jeuIndiceCrt].statistique.coups.x        = 0;
	G_jeu[G_jeuIndiceCrt].statistique.coups.y        = 0;

}

/*************************************************************************/
/* Nom : initialise_tableau_commande                                     */
/*                                                                       */
/* Role : Fonction permettant d'initialiser le tableau de commande du jeu*/
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 06/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/

void initialise_tableau_commande ( void )
{
	/* bouton coup precedent */
	dialogue_bouton_relache(162, 18, 11, 20);
	drwstring(1, TEXTE, FOND, "<", 164, 22);

	/* bouton coup suivant */
	dialogue_bouton_relache(178, 18, 11, 20);
	drwstring(1, TEXTE, FOND, ">", 180, 22);

	/* bouton conseil */
	dialogue_bouton_relache(198, 18, 62, 20);
	drwstring(1, TEXTE, FOND, "Conseil", 201, 22);

	/* bouton stop */
	dialogue_bouton_relache(440, 18, 36, 20);
	drwstring(1, TEXTE, FOND, "Stop", 443, 22);

	/* version d'othello */
	drwstring(1, TEXTE, FOND, G_version, 350, 22);

}

/*************************************************************************/
/* Nom : compte_pions                                                    */
/*                                                                       */
/* Role : Fonction permettant de compter le nombre de pions de chaque    */
/*        joueur                                                         */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void compte_pions(void)
{
	int i,j; /* compteur pour les boucles */
	int nombreBlanc, nombreNoir; /* Nombre de pions par couleur */


	nombreNoir  = 0;
	nombreBlanc = 0;

	raz_zone_score();

	/* on compte le nombre de pions de chaque couleur */
	for(i=1;i<9;i++)
	{
		for(j=1;j<9;j++)
		{
			if (G_board[i][j]==NOIR)  nombreNoir++;
			if (G_board[i][j]==BLANC) nombreBlanc++;
		}
	}

	/* affichage des nombres de pions */
	affiche_nombre ( 40, 120+20, nombreNoir);
	affiche_nombre (550, 120+20, nombreBlanc);

	/* mise a jour des statistques */
	G_statistique[NOIR].score  = nombreNoir;
	G_statistique[BLANC].score = nombreBlanc;
}


/*************************************************************************/
/* Nom : raz_zone_score                                                  */
/*                                                                       */
/* Role : Fonction permettant d'effacer la zones des scores              */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 06/04/1997 | Modification de la facon d'effacer l'ancien score  */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void raz_zone_score(void)
{
	drwfillbox(1, FOND,  40, 120+20,  80, 150+20);
	drwfillbox(1, FOND, 550, 120+20, 590, 150+20);

}


/*************************************************************************/
/* Nom : affiche_nombre                                                  */
/*                                                                       */
/* Role : Fonction permettant d'afficher un nombre graphique             */
/*                                                                       */
/*                                                                       */
/* Entree : x : coordonnees en abcisse                                   */
/*          y : coordonnees en ordonnee                                  */
/*          nombre : nombre a afficher                                   */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void affiche_nombre (int x, int y, int nombre)
{
	char buf[3];
	int i;

	/* conversion du nombre sur deux caracteres */
	sprintf(buf, "%02d\0", nombre);

	/* chiffre a afficher max deux caracteres */
	for(i=0; i < 2; i++)
	{
		spritegap(43,
			  x + i * (TAILLE_CHIFFRE_X + 1),
			  y,
			  G_ptrNombre[(buf[i] - 48)],
			  G_ptrNombreTmp);
	}
}

/*************************************************************************/
/* Nom : affiche_pions                                                   */
/*                                                                       */
/* Role : Fonction permettant d'afficher le pions sur le damier          */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 24/03/1997 | Ajout de l'effet de retournement des pions         */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void affiche_pions(void)
{
   int i,j;          /* variables pour les boucles -> cases du damier */
   int type;         /* type des pions a afficher */
   int pionX, pionY; /* coordonnees des pions a afficher     */

   int  blancVersNoir[4] = { BLANC_OVALE, NOIR_BLANC, NOIR_OVALE, NOIR };
   int  noirVersBlanc[4] = { NOIR_OVALE, BLANC_NOIR, BLANC_OVALE, BLANC };

   for (type = 0; type < 4; type++)
   {
	for(i=1; i<9; i++)
	{
		for(j=1; j<9; j++)
		{
			if ((G_board[i][j]) && (G_board[i][j] != G_boardMem[i][j]))
			{
				pionX = (i-1) * 43+149;
				pionY = (j-1) * 43+ 76;

				if (G_boardMem[i][j] == BLANC)
					spritegap(255,
						  pionX,
						  pionY,
						  G_ptrPionJeu[blancVersNoir[type]],
						  G_ptrPion);
				else
					spritegap(255,
						  pionX,
						  pionY,
						  G_ptrPionJeu[noirVersBlanc[type]],
						  G_ptrPion);

			}
		}
	}
//	delay(50);
	delay(70);
   }


	/* copie du damier en zone tampon */
	memcpy(G_boardMem, G_board, 100);

}

/*************************************************************************/
/* Nom : choix_joueur                                                    */
/*                                                                       */
/* Role : Fonction permettant d'initier le jeu possibilite de determiner */
/*        qui commence en premier                                        */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/02/1997 | ajout de la variable G_joueurAdverse               */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/


int choix_joueur ( void )
{
	int typeJeu;

	G_joueurCourant = NOIR ; /* ce sont les noirs qui commencent */
	G_ordinateur    = VIDE;

	/*******************************/
	/* on determine le type de jeu */
	/*******************************/

	/* Combat entre ordinateur */
	if (G_choixTypeJeu[0] !=0 && G_choixTypeJeu[1] != 0)
		typeJeu = 1;
	else
		typeJeu = 0;

	/* Humain noir contre ordinateur blanc */
	if (G_choixTypeJeu[0] == 0 && G_choixTypeJeu[1] != 0)
		G_ordinateur = BLANC;

	/* Humain blanc contre ordinateur noir */
	if (G_choixTypeJeu[0] != 0 && G_choixTypeJeu[1] == 0)
		G_ordinateur = NOIR;


	change_curseur(G_joueurCourant); /* changement curseur */

	return (typeJeu);
}


/*************************************************************************/
/* Nom : change_joueur                                                   */
/*                                                                       */
/* Role : Fonction permettant de changer de joueur (au prochain de jouer)*/
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/02/1997 | Ajout de la variable G_joueurAdverse               */
/*     |            |                                                    */
/* PDB | 18/04/1997 | Ajout effet de retournement pour le pion designant */
/*     |            | le joueur courant                                  */
/*     |            |                                                    */
/*************************************************************************/

void change_joueur(void)
{
	/* variables pour les effets de retournement */

	int  blancVersNoir[4] = { BLANC_OVALE, NOIR_BLANC, NOIR_OVALE, NOIR };
	int  noirVersBlanc[4] = { NOIR_OVALE, BLANC_NOIR, BLANC_OVALE, BLANC };
	int  type;


	G_joueurCourant = -G_joueurCourant + 3; /* on passe a l'autre joueur */

	/* Affichage du joueur courant dans la zone determinant */
	/* le tour du joueur */

	for (type = 0; type < 4; type ++)
	{
		/* effacement de la zone du pion */
		drwfillbox(1, FOND, 300, 10, 335, 45);

		/* Affichage etape */
		if (G_joueurCourant == NOIR) /* on devient noir */
			spritegap(44,
				  300,
				  10,
				  G_ptrPionJeu[blancVersNoir[type]],
				  G_ptrPion);

		else /* on devient blanc */

			spritegap(44,
				  300,
				  10,
				  G_ptrPionJeu[noirVersBlanc[type]],
				  G_ptrPion);
		delay(50);
	}

	change_curseur(G_joueurCourant); /* changement curseur */
}

/*************************************************************************/
/* Nom : jouer_coup                                                      */
/*                                                                       */
/* Role : Fonction permettant de jouer un coup                           */
/*        Cette fonction permet aussi d'ameliorer l'effet des            */
/*        retournement des pions                                         */
/*                                                                       */
/*                                                                       */
/* Entree : caseX, caseY : coup joue                                     */
/*          couleur      : couleur du joueur                             */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 23/03/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void jouer_coup( char caseX, char caseY, int couleur)
{
	int pionX, pionY;


	/* on met a jour le damier avec le coup joue */
	G_board[caseX][caseY]    = couleur;
	G_boardMem[caseX][caseY] = couleur;


	/* On affiche le coup joue */
	pionX = (caseX-1) * 43+149;
	pionY = (caseY-1) * 43+ 76;

	/* si la couleur est vide, on ecrase ce qu'il y a sur la case */
	if (couleur == VIDE)
		spritegap(255,
			  pionX,
			  pionY,
			  G_ptrPionJeu[couleur],
			  G_ptrPion);
	else
		spritegap(44,
			  pionX,
			  pionY,
			  G_ptrPionJeu[couleur],
			  G_ptrPion);
}


/*************************************************************************/
/* Nom : coup_precedent                                                  */
/*                                                                       */
/* Role : Fonction permettant de gerer le clic sur le bouton coup        */
/*        precedent                                                      */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 19/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 30/06/1997 | Ajout beep sur clic precedent impossible           */
/*     |            |                                                    */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void coup_precedent ( void )
{
	int caseX, caseY, couleurJoueur;

	/* Restauration du coup precedent */
	if (G_jeuIndiceCrt != 0)
	{

		/* couleur du coup joue */
		couleurJoueur = G_jeu[G_jeuIndiceCrt].couleur;

		G_jeuIndiceCrt--;


//		while ( (couleurJoueur == G_ordinateur) && (G_jeuIndiceCrt != 0))
//		{
//			couleurJoueur = G_jeu[G_jeuIndiceCrt].couleur;
//			G_jeuIndiceCrt--;
//		}

		memcpy(G_board, G_jeu[G_jeuIndiceCrt].damier, 100);

		G_statistique[couleurJoueur].score	    = G_jeu[G_jeuIndiceCrt].statistique.score;
		G_statistique[couleurJoueur].mobilite	    = G_jeu[G_jeuIndiceCrt].statistique.mobilite;
		G_statistique[couleurJoueur].evaluation     = G_jeu[G_jeuIndiceCrt].statistique.evaluation;
		G_statistique[couleurJoueur].nombreFeuilles = 0; /* G_jeu[G_jeuIndiceCrt].statistique.nombreFeuilles;*/
		G_statistique[couleurJoueur].profondeur     = 0; /* G_jeu[G_jeuIndiceCrt].statistique.profondeur;*/
		G_statistique[couleurJoueur].coups.x	    = 0; /* G_jeu[G_jeuIndiceCrt].statistique.coups.x;*/
		G_statistique[couleurJoueur].coups.y	    = 0; /* G_jeu[G_jeuIndiceCrt].statistique.coups.y;*/

		for (caseX = 1; caseX < 9; caseX++)
			for (caseY = 1; caseY < 9; caseY++)
				jouer_coup(caseX, caseY, G_board[caseX][caseY]);

		statistique(couleurJoueur);

		/* affichage du joueur courant */
		if (G_jeuIndiceCrt == 0)
			couleurJoueur = NOIR;

		G_joueurCourant = -couleurJoueur + 3;
		change_joueur();
	}
	else /* on est au debut du jeu */
	{
		sound(1000);
		delay(20);
		sound(50);
		delay(10);
		nosound();

		/* Affichage dans la zone d'aide en ligne */
		dialogue_aide_en_ligne("Vous ne pouvez pas revenir en arrire.");
	}


}

/*************************************************************************/
/* Nom : coup_suivant                                                    */
/*                                                                       */
/* Role : Fonction permettant de gerer le clic sur le bouton coup        */
/*        suivant                                                        */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 19/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 30/06/1997 | Ajout beep sur clic suivant impossible             */
/*     |            |                                                    */
/*************************************************************************/

void coup_suivant ( void )
{
	int caseX, caseY, couleurJoueur;

	/* Restauration du coup suivant */
	if (G_jeuIndiceCrt != G_jeuIndiceMax)
	{
		G_jeuIndiceCrt++;

		couleurJoueur = G_jeu[G_jeuIndiceCrt].couleur;

		memcpy(G_board, G_jeu[G_jeuIndiceCrt].damier, 100);


		G_statistique[couleurJoueur].score	    = G_jeu[G_jeuIndiceCrt].statistique.score;
		G_statistique[couleurJoueur].mobilite	    = G_jeu[G_jeuIndiceCrt].statistique.mobilite;
		G_statistique[couleurJoueur].evaluation     = G_jeu[G_jeuIndiceCrt].statistique.evaluation;
		G_statistique[couleurJoueur].nombreFeuilles = G_jeu[G_jeuIndiceCrt].statistique.nombreFeuilles;
		G_statistique[couleurJoueur].profondeur     = G_jeu[G_jeuIndiceCrt].statistique.profondeur;
		G_statistique[couleurJoueur].coups.x	    = G_jeu[G_jeuIndiceCrt].statistique.coups.x;
		G_statistique[couleurJoueur].coups.y	    = G_jeu[G_jeuIndiceCrt].statistique.coups.y;

		G_appel = G_statistique[couleurJoueur].nombreFeuilles;

		for (caseX = 1; caseX < 9; caseX++)
			for (caseY = 1; caseY < 9; caseY++)
				jouer_coup(caseX, caseY, G_board[caseX][caseY]);

		/* affichage des statistique du coup joue */
		statistique(couleurJoueur);

		/* affichage du joueur courant */
		G_joueurCourant = couleurJoueur;
		change_joueur();
	}
	else
	{
		sound(1000);
		delay(20);
		sound(50);
		delay(10);
		nosound();
		/* Affichage dans la zone d'aide en ligne */
		dialogue_aide_en_ligne("Vous ne pouvez pas avancer.");
	}



}

/*************************************************************************/
/* Nom : memorise_jeu                                                    */
/*                                                                       */
/* Role : Fonction permettant de memoriser les coups du jeu              */
/*                                                                       */
/*                                                                       */
/* Entree : joueurCourant : couleur du joueur demandant de recalculer    */
/*                          les statistiques                             */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void memorise_jeu (int joueurCourant)
{
	/* on modifie les indices sur la table G_jeu */
	G_jeuIndiceCrt++;
	G_jeuIndiceMax = G_jeuIndiceCrt;

	/* Memorisation du jeu courant */
	memcpy(G_jeu[G_jeuIndiceCrt].damier, G_board, 100);

	G_jeu[G_jeuIndiceCrt].couleur = joueurCourant;

	G_jeu[G_jeuIndiceCrt].statistique.score          = G_statistique[joueurCourant].score;
	G_jeu[G_jeuIndiceCrt].statistique.mobilite       = G_statistique[joueurCourant].mobilite;
	G_jeu[G_jeuIndiceCrt].statistique.evaluation     = G_statistique[joueurCourant].evaluation;
	G_jeu[G_jeuIndiceCrt].statistique.nombreFeuilles = G_statistique[joueurCourant].nombreFeuilles;
	G_jeu[G_jeuIndiceCrt].statistique.profondeur     = G_statistique[joueurCourant].profondeur;
	G_jeu[G_jeuIndiceCrt].statistique.coups.x        = G_statistique[joueurCourant].coups.x;
	G_jeu[G_jeuIndiceCrt].statistique.coups.y        = G_statistique[joueurCourant].coups.y;

}

/*************************************************************************/
/* Nom : conseil_coup                                                    */
/*                                                                       */
/* Role : Fonction permettant de conseiller un coup a un joueur          */
/*                                                                       */
/*                                                                       */
/* Entree : joueurCourant : couleur du joueur demandant le conseil       */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/05/1997 | Restriction de la zone du curseur de la souris lors*/
/*     |            | de la recherche en profondeur                      */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void conseil_coup (int joueurCourant)
{
	char lettres [9][2] = {" ", "A", "B", "C", "D", "E", "F", "G", "H"};
	char chiffres[9][2] = {" ", "1", "2", "3", "4", "5", "6", "7", "8"};

	int profondeur; /* profondeur de la recherche du meilleur coup */

	int  scoreCoup = 0; /* score du meilleur coup */
	char caseX, caseY;  /* coup a jouer */
	int  nombrePion;    /* nombre de pion sur le damier */

	char buffer[MAX_BUFFER]; /* chaine tampon */


	/* le curseur de la souris peut etre visible */
	change_curseur(ORDINATEUR);
	mouse_visible(TRUE);

	/* Le conseil est base sur une recherche du meilleur coup */
	/* avec un niveau expert */

	nombrePion = G_statistique[NOIR].score + G_statistique[BLANC].score;

	if (nombrePion < 14)
		profondeur = PROFONDEUR_EXPERT + 2;

	else if (nombrePion > (LIMITE_EXPERT))
		profondeur = 64 - nombrePion;

	else
		profondeur = PROFONDEUR_EXPERT;


	/* On restreint la zone de la souris */
	mousestatus(&G_sourisX, &G_sourisY, &G_sourisBouton);
	mouserangeset(0, 0, 639, 440);
	mouselocset(G_sourisX, G_sourisY);

	/* vidage du buffer clavier */
	while(kbhit())
		getch();


	/* recherche du meilleur coup avec la methode minmax ou alpha_beta */
	G_autoriseArret = TRUE;
	G_stopAlphaBeta = FALSE;
	dialogue_aide_en_ligne("Touche <ECHAP> pour interrompre la recherche.");

//	min_max (G_board, profondeur, joueurCourant, &caseX, &caseY, &scoreCoup);

	alpha_beta (G_board, profondeur, joueurCourant, &caseX, &caseY, &scoreCoup, 0, 0);

	/* On affiche le coup conseille */
	sprintf(buffer, "je vous conseille de jouer en %s%s (%ld).", lettres[caseX], chiffres[caseY], G_appel);

	dialogue_aide_en_ligne(buffer);

	/* on raz la variable G_appel */
	G_appel = 0;

	/* On supprime la restriction de la zone de la souris */
	mousestatus(&G_sourisX, &G_sourisY, &G_sourisBouton);
	mouserangeset(0, 0, 639, 479);
	mouselocset(G_sourisX, G_sourisY);

	mouse_visible(FALSE);
	change_curseur(joueurCourant);

}

/*************************************************************************/
/* Nom : jeu_normal                                                      */
/*                                                                       */
/* Role : Fonction permettant de jouer en mode normal a othello          */
/*                                                                       */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 27/04/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/05/1997 | Deport de le gestion d'une reprise de partie       */
/*     |            |                                                    */
/* PDB | 29/06/1997 | Modification des tests pour la reprise d'une partie*/
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void jeu_normal ( void )
{
	char buffer[MAX_BUFFER] ;
	char nomImage[MAX_BUFFER] ;
	char choixValide = TRUE; /* choix d'un type de jeu valide */
	char typeJeu   ;
	char reprise = NOK;      /* reprise d'une partie */
	char nomPartie[MAX_BUFFER]; /* nom de la partie a charger */
	char bouton;



	/* fichier image du jeu */
	sprintf(nomImage, "%s", "images\\otho.pcx\0");

	while (choixValide)
	{
		/* appel du dialogue permettant de preparer le type de jeu */

		G_ordinateur = VIDE;
		change_curseur(BLANC);
		choixValide = dialogue_type_jeu ();

		if (choixValide == ANNULER)
			break;

		/* on ecrase l'image par elle meme pour effacer le dialogue */
//		palioauto(G_gifPalette, 0, 255, -50);
		charge_image(nomImage, RES640);

		initialise_jeu();

//		palioauto(G_gifPalette, 0, 255, -128);
//		video_on();
//		palioauto(G_gifPalette, 0, 255, 50);

		/* Reprise d'une partie sauvegardee */
		if (G_reprise == TRUE)
		{
			do
			{
				/* saisie du nom de la partie a reprendre */
				dialogue_aide_en_ligne("");

				bouton = dialogue_saisie("Nom de la partie :", G_memoriseNomPartie, 8);

				if ( bouton == OK)
				{
					sprintf(nomPartie, "data\\%s.dat", G_saisie.chaine);
					sprintf(buffer, "Chargement de de la partie %s", G_saisie.chaine);

					dialogue_aide_en_ligne(buffer);

					reprise = charge_partie ( nomPartie );
				}

			} while (!((bouton == OK && reprise == OK) || (bouton == ANNULER)));

			if (bouton == ANNULER) /* On annuler la visualisation */
			{
				reprise = NOK;
			}


			G_reprise = FALSE;
		}

		/* on initialise les parametres du jeux */
		typeJeu = choix_joueur();


		switch (typeJeu)
		{

			case 0:

				/* jeux a deux joueurs */
				jeu_2joueurs(reprise);
				break;

			case 1:
				/* ordinateur contre ordinateur */
				ordinateur_vs_ordinateur(reprise);
				break;

			default:
				break;
		}

		reprise = NOK; /* pas de reprise */

	}
}
