#include <stdio.h>

#include "include\svgacc.h"
#include "include\prototyp.h"
#include "include\global.h"
#include "include\keyboard.h"


/*************************************************************************/
/* Nom : change_curseur                                                  */
/*                                                                       */
/* Role : Fonction permettant de changer de curseur de la souris         */
/*                                                                       */
/* Entree : curseur : numero du curseur                                  */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 25/12/1996 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 21/04/1997 | On selectionne le curseur demande sans filtrer     */
/*     |            | le curseur de l'ordinateur                         */
/*     |            |                                                    */
/*************************************************************************/


void change_curseur ( int curseur )
{
//	if (G_ordinateur == curseur)
//		mousecursorset(&G_curseurSouris[ORDINATEUR]);
//	else
		mousecursorset(&G_curseurSouris[curseur]);
}

/*************************************************************************/
/* Nom : mouse_attente                                                   */
/*                                                                       */
/* Role : Fonction permettant d'attendre un appui bouton souris          */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 25/12/1996 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 06/05/1997 | Ajout gestion affichage curseur souris             */
/*     |            |                                                    */
/* PDB | 25/05/1997 | Ajout de la possibilite de realiser des captures   */
/*     |            | d'ecrans sur clic droit de la souris               */
/*     |            |                                                    */
/* PDB | 21/06/1997 | Ajout gestion temps de reflexion                   */
/*     |            |                                                    */
/*************************************************************************/

void mouse_attente (void)
{
	mouse_visible(TRUE); /* affichage curseur souris */

	do
	{
		mousestatus(&G_sourisX, &G_sourisY, &G_sourisBouton);

		/* une saisie est en cours ? */
		if (G_saisieEnCours && iskey())
		{
			/* on sort de l'attente -> traitement du caractere */
			G_sourisBouton = 5;
		}

		/* On realise une capture si clic bouton droit */
		if (G_sourisBouton == 2)
			capture_ecran();

		gere_reflexion();
	}
	while (!G_sourisBouton);

	mouse_visible(FALSE); /* masquage curseur souris */

}

/*************************************************************************/
/* Nom : mouse_attente_relache                                           */
/*                                                                       */
/* Role : Fonction permettant d'attendre un relache bouton de la souris  */
/*                                                                       */
/* Entree : -                                                            */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 25/12/1996 | Creation de la fonction.                           */
/*     |            |                                                    */
/* PDB | 06/05/1997 | Ajout gestion affichage curseur souris             */
/*     |            |                                                    */
/* PDB | 21/06/1997 | Ajout gestion temps de reflexion                   */
/*     |            |                                                    */
/*     |            |                                                    */
/*************************************************************************/

void mouse_attente_relache (void)
{
	mouse_visible(TRUE); /* affichage curseur souris */

	do
	{
		mousestatus(&G_sourisX, &G_sourisY, &G_sourisBouton);
		gere_reflexion();
	}
	while (G_sourisBouton);

	mouse_visible(FALSE); /* masquage curseur souris */

}


/*************************************************************************/
/* Nom : mouse_zone                                                      */
/*                                                                       */
/* Role : Fonction permettant de savoir si les coordonnees sont comprises*/
/*        dans la zone entree en parametre                               */
/*                                                                       */
/* Entree : x1 : -+		                                         */
/*          x2 :  |                                                      */
/*          y1 :  |-> coordonnees de la zone                             */
/*          y2 : -+                                                      */
/*                                                                       */
/*         x1,y1                                                         */
/*	     +-------------------+                                       */
/*	     |                   |                                       */
/*	     |                   |                                       */
/*	     +-------------------+                                       */
/*			       x2,y2                                     */
/*                                                                       */
/* Sortie : 1 si le curseur est dans la zone, 0 sinon                    */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 30/01/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/

char mouse_zone ( int x1, int x2, int y1, int y2 )
{
	if (   G_sourisX > x1
	    && G_sourisX < x2
	    && G_sourisY > y1
	    && G_sourisY < y2 )
		return TRUE; /* OK le curseur se trouve dans la zone */
	else
		return FALSE; /* KO le curseur ne se trouve pas dans la zone */
}

/*************************************************************************/
/* Nom : mouse_visible                                                   */
/*                                                                       */
/* Role : Fonction permettant de rendre le curseur de la souris visible  */
/*        ou invisible                                                   */
/*        Cela permet de s'assurer que l'on ne realise pas deux appels   */
/*        aux fonctions mousehide() et mouseshow() qui bloque le jeu     */
/*                                                                       */
/* Entree : etatCurseur : TRUE  -> curseur visible                       */
/*                        FALSE -> curseur masque                        */
/* Sortie : -                                                            */
/*                                                                       */
/* ===================================================================== */
/* Nom | Date       | Description                                        */
/* ----+------------+--------------------------------------------------- */
/* PDB | 20/02/1997 | Creation de la fonction.                           */
/*     |            |                                                    */
/*************************************************************************/

void mouse_visible ( char etatCurseur )
{
	/* on masque la souris si cela n'a pas deja ete realise */

	if (!etatCurseur && G_etatCurseur)
	{
		mousehide();
		G_etatCurseur = FALSE;
	}
	else if (etatCurseur && !G_etatCurseur)

	/* on rend le curseur visible si cela n'a pas deja ete realise */

	{
		mouseshow();
		G_etatCurseur = TRUE;
	}

}
