/* temps.c - manage time for the game */

/* Copyright 1997-2001 Otho team. */

/*
modification history
--------------------
15b,25oct01,pdb  fixed bug about minutes display.
15a,21oct01,pdb  based on Otho 1.4b.
*/

/*
DESCRIPTION
This module gives services about the time
information during a game
*/

/* includes */
   
#include <time.h>
#include <stdio.h>

#include "include\global.h"
#include "include\prototyp.h"
#include "include\svgacc.h"
#include "include\couleur.h"

/*******************************************************************************
*
* affiche_temps - display play time
*
* This routine displays effectif play time of a player
*
* RETURNS: N/A.
*
*/

void affiche_temps
	(
	int couleurJoueur	/* player for which the time must be displayed */
	)
	{
	char 	temps[20];
	char	etatCurseur;
	int  	minutes;
	int  	hours;
	int  	seconds;
	time_t 	tempsJeu;

	int 	x, y;

	switch (couleurJoueur)
		{
		case NOIR:	 /* coordonnees pour l'affichage du temps pour les noirs */
			x = 20;
			y = 390;
			tempsJeu = G_temps[NOIR];
			break;

		case BLANC:	 /* coordonnees pour l'affichage du temps pour les blancs */
			x = 530;
			y = 390;
			tempsJeu = G_temps[BLANC];
			break;

		default:
			return;
		}

	/* masquage du curseur de la souris */
	etatCurseur = G_etatCurseur;
	mouse_visible(FALSE);

	/* conversion du temps en chaine de caractere */

	hours     = (int) (tempsJeu / 3600);
	tempsJeu -= (hours*3600);
    minutes   = (int) (tempsJeu / 60);
    tempsJeu -= (minutes*60);
    seconds   = (int) tempsJeu;

	sprintf(temps, "%02i:%02i:%02i", hours, minutes, seconds);

	/* Libelle temps */
	drwstring(1, TEXTE, FOND, "Temps :", x, y);

	/* affichage du temps */
	statistique_affiche_donnee(x, y+20, temps, 8);

	/* on restaure l'etat du curseur de la souris */
	mouse_visible(etatCurseur);
	}

 /*******************************************************************************
*
* debut_reflexion - start the time counting
*
* This routine is called at the start of a game. It starts the time counting
* of the game.
*
* RETURNS: N/A.
*
*/

void debut_reflexion ( void )
	{
	G_gestionTemps = TRUE;
	G_tempsCourant = time (NULL);
	}

/*******************************************************************************
*
* fin_reflexion - end of time counting
*
* This routine is called when the player has finished his reflexion.
* It updates the display about the time information.
*
* RETURNS: N/A.
*
*/

void fin_reflexion
	(
	int joueurCourant 	/* current player */
	)
	{
	G_gestionTemps = FALSE;

	affiche_temps(joueurCourant);
	}

/*******************************************************************************
*
* gere_reflexion - manage the thinking time
*
* This routine manages the thinking times duration of current player.
*
* RETURNS: N/A.
*
*/

void gere_reflexion ( void )
	{
	time_t temps;
	time_t delta;

	/* la gestion du temps est autorisee */
	if ( G_gestionTemps == TRUE )
		{
		/* temps courant */
		temps = time (NULL);

		delta = temps - G_tempsCourant;

		/* affichage du temps toutes les secondes */
		if ( delta >= 1 )
			{
			/* affichage */
			G_temps[G_joueurCourant] += delta;
			
			affiche_temps(G_joueurCourant);

			/* memorisation */
			G_tempsCourant = temps;
			}
		}
	}
